# FAQ

Setup & installation guide:

- {doc}`faq/setup`

Edges cases, warnings, and errors:

- {doc}`faq/initialize`
- {doc}`faq/initialize-set-env`
- {doc}`faq/inconsistent-packages-parents-store`
- {doc}`faq/inconsistent-packages-parents-no-store`
- {doc}`faq/example-project`
- {doc}`faq/example-project-uninitialized`
- {doc}`faq/example-after-init-set-filename`
- {doc}`faq/publish-set-version`
- [Publish without title](faq/publish-without-title)
- {doc}`faq/publish-without-saving`
- {doc}`faq/publish-not-last-cell`
- {doc}`faq/title-not-at-top`
- {doc}`faq/publish-wrapper`
- {doc}`faq/trigger-exit-upon-init`
- {doc}`faq/not-initialized`
- {doc}`faq/internal-functions`
- {doc}`faq/set-env-via-environment-var`
- {doc}`faq/header-author-field`
- {doc}`faq/cell-source-string`

```{toctree}
:maxdepth: 1
:hidden:

faq/setup
faq/initialize
faq/initialize-set-env
faq/inconsistent-packages-parents-store
faq/inconsistent-packages-parents-no-store
faq/example-project
faq/example-project-uninitialized
faq/example-after-init-set-filename
faq/publish-set-version
faq/publish-without-title
faq/publish-without-saving
faq/publish-not-last-cell
faq/publish-wrapper
faq/title-not-at-top
faq/trigger-exit-upon-init
faq/not-initialized
faq/internal-functions
faq/set-env-via-environment-var
faq/header-author-field
faq/cell-source-string
```
